#  ____                        _
# / ___| _ __  _   _ _ __ __ _(_) ___
# \___ \| '_ \| | | | '__/ _` | |/ _ \
#  ___) | |_) | |_| | | | (_| | | (_) |
# |____/| .__/ \__, |_|  \__,_|_|\___/
#       |_|    |___/
#                 By Adriano P. Almeida

__title__ = 'spyraio'
__version__ = '0.0.9'
__description__ = 'Spyraio it\'s a Python package which contains some functions to lightning forecasting.'
__url__ = 'https://github.com/AdrianoPereira/spyraio'
__keywords__ = 'weather lightning nowcasting meteorology radar'
__author__ = 'Adriano P. Almeida'
__author_email__ = 'adriano.almeida@inpe.br'
__license__ = 'MIT'
__copyright__ = 'Copyright 2019 Adriano/INPE'